@@ -1,6 +1,6 @@
 ##############################################################################
 #
-#  Data::Tools perl module
+#  Data::Tools::Time perl module
 #  Copyright (c) 2013-2022 Vladi Belperchinov-Shabanski "Cade" 
 #        <cade@noxrun.com> <cade@bis.bg> <cade@cpan.org>
 #  http://cade.noxrun.com/  
@@ -16,7 +16,7 @@ use Data::Tools;
 use Date::Calc qw(:all);
 use Time::JulianDay;
 
-our $VERSION = '1.28';
+our $VERSION = '1.29';
 
 our @ISA    = qw( Exporter );
 our @EXPORT = qw(
@@ -36,6 +36,7 @@ our @EXPORT = qw(
                 julian_date_add_ymd
                 julian_date_to_ymd
                 julian_date_from_ymd
+                julian_date_from_md
 
                 julian_date_goto_first_dom
                 julian_date_goto_last_dom
@@ -44,6 +45,8 @@ our @EXPORT = qw(
                 julian_date_month_days
                 julian_date_get_dow
 
+                julian_date_to_iso
+
                 utime_from_julian_date
                 utime_from_ymdhms
                 utime_to_ymdhms
@@ -224,6 +227,11 @@ sub get_year_month_days
   return Days_in_Month( @_ );
 }
 
+sub julian_date_from_utime
+{
+  return local_julian_day( shift() );
+}
+
 # return julian date, moved with positive or negative deltas ( y, m, d ) 
 sub julian_date_add_ymd
 {
@@ -255,13 +263,33 @@ sub julian_date_to_ymd
 sub julian_date_from_ymd
 {
   my $y = shift; # set year
-  my $m = shift; # set month
-  my $d = shift; # set day
+  my $m = shift || 1; # set month
+  my $d = shift || 1; # set day
 
   my $wd = julian_day( $y, $m, $d );
   return $wd;
 }
 
+# return julian date from month and day only 
+# finds closest date which matches, regardless if it is in the future or past
+sub julian_date_from_md
+{
+  my $mon = shift;
+  my $day = shift || 1;
+
+  my $now = local_julian_day( time() );
+  my ( $cy ) = julian_date_to_ymd( $now );
+  
+  my $cd = julian_date_from_ymd( $cy, $mon, $day );
+
+  return $cd if $now == $cd;
+
+  my $oy = $cy + ( $cd > $now ? -1 : +1 );
+  my $od = julian_date_from_ymd( $oy, $mon, $day );
+
+  return abs( $cd - $now ) < abs( $od - $now ) ? $cd : $od;
+}
+
 # return julian date, moved to the first day of its month
 sub julian_date_goto_first_dom
 {
@@ -305,6 +333,11 @@ sub julian_date_month_days
   return Days_in_Month( ( julian_date_to_ymd( $d ) )[0,1] );
 }
 
+sub julian_date_to_iso
+{
+  return join "-", julian_date_to_ymd( shift() );
+}
+
 ##############################################################################
 
 sub utime_from_julian_date
@@ -321,7 +354,7 @@ sub utime_from_ymdhms
 
 sub utime_to_ymdhms
 {
-  return Localtime(shift());
+  return Localtime( shift() );
 }
 
 # returns local julian day and time from unix time
